local L = LibStub( "AceLocale-3.0" ):GetLocale( "UnderHood" )

UnderHood = LibStub( "AceAddon-3.0" ):NewAddon( "UnderHood", "AceEvent-3.0", "AceConsole-3.0" )

UnderHood.Version = "1.1"
UnderHood.Revision = string.match( "$Revision: 64509 $", "%d+" )

UnderHood.playerLoggedIn = false

function UnderHood:OnInitialize()
	self.alpha = 1
	self.ParentFrame = CreateFrame( "Frame", "UnderHoodParent", UIParent )
	self.ParentFrame:SetWidth( 200 )
	self.ParentFrame:SetHeight( 200 )
	self.ParentFrame:SetAlpha( 1 )
	self.ParentFrame:SetPoint( "CENTER", UIParent, "CENTER" )
	self.ParentFrame:Show()
	
	self.OptionsHelper:Initialize()
	self:SetupConfig()
	self:SetupOptions()

	self:Print( string.format( L["Version %s.%d. Use |cff00ff00/uh|r to configure."], self.Version, self.Revision ) )
end

function UnderHood:OnEnable()
	self.inCombat = InCombatLockdown()

	self:RegisterEvent( "PLAYER_LOGIN" )	
	self:RegisterEvent( "PLAYER_REGEN_DISABLED" )
	self:RegisterEvent( "PLAYER_REGEN_ENABLED" )
	self:RegisterEvent( "PLAYER_TARGET_CHANGED", "UpdateAlpha" )
	self:RegisterEvent( "UNIT_HEALTH", "UpdateAlpha" )
	self:RegisterEvent( "UNIT_MANA", "UpdateAlpha" )
	
	self:UpdateBlizzardFrames()
	
	self:UpdateAlpha()
end

function UnderHood:PLAYER_LOGIN()
	self.playerLoggedIn = true
	
	self:SendMessage( "UnderHood_PlayerLogin" )
end

function UnderHood:PLAYER_REGEN_DISABLED()
	self.inCombat = true
	
	self:UpdateAlpha()
end

function UnderHood:PLAYER_REGEN_ENABLED()
	self.inCombat = nil
	
	self:UpdateAlpha()
end

function UnderHood:InConfigMode()
	return self.db.profile.general.config
end

function UnderHood:UpdateAlpha()
	local alpha
	
	if self.db.profile.general.config then
		alpha = 1
	elseif self.inCombat then
		alpha = self.db.profile.alpha.combat
	elseif UnitExists( "target" ) then
		alpha = self.db.profile.alpha.target
	elseif UnitHealth( "player" ) ~= UnitHealthMax( "player" ) or UnitMana( "player" ) ~= UnitManaMax( "player" ) then
		alpha = self.db.profile.alpha.regen
	else
		alpha = self.db.profile.alpha.ooc
	end
	
	if alpha ~= self.alpha then
		self.alpha = alpha
		
		self.ParentFrame:SetAlpha( alpha )
	end
end

function UnderHood:Debug( ... )
	if not( self.db ) or not( self.db.profile.general.debug ) then return end
	
	local count = select( "#", ... );
	local text = nil;
	
	if count == 0 then text = ""
	elseif count == 1 then text = tostring( select( 1, ... ) )
	elseif type( select( 1, ... ) ) == "string" and strfind( select( 1, ... ), "%%" ) then text = string.format( ... )
	else
		text = "";
		
		for i=1, count do
			if i > 1 then
				text = text..", "
			end
			
			text = text..tostring( select( i, ... ) )
		end
	end
	
	DEFAULT_CHAT_FRAME:AddMessage( "|cffffffffUnderHood |r|cff00ffff(Debug)|r|cffffffff: |r"..text );
end
